/**
 * NOTE: THIS IS A GENERATED FILE. PLEASE CONSULT THE ORIGINAL IDL FILE
 * FOR THE FULL DOCUMENTION AND LICENSE.
 *
 * @see <a href="http://lxr.mozilla.org/mozilla/search?string=interface+nsIRegistryEnumerat">
 **/

package org.mozilla.xpcom;

public interface nsIRegistryEnumerator extends nsIEnumerator
{
  public static final String NS_IREGISTRYENUMERATOR_IID =
    "{8cecf236-1dd2-11b2-893c-f9848956eaec}";

  public String currentItemInPlaceUTF8(long[] arg1);

}
